package ua.com.dxrkness.controller;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.CorsRegistry;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
import org.springframework.web.servlet.function.RouterFunction;
import org.springframework.web.servlet.function.RouterFunctions;
import org.springframework.web.servlet.function.ServerResponse;

@Configuration
public class S3FileHandlerConfig implements WebMvcConfigurer {
    @Bean
    public RouterFunction<ServerResponse> router(S3FileHandler handler) {
        return RouterFunctions.route()
                .path("/files", b -> b
                        .GET("/{*path}", handler::downloadFile)
                        .POST(handler::uploadFile)
                )
                .path("/dirs", b -> b
                        .GET("/{*path}", handler::listing)
                        .POST(handler::createDirectory)
                )
                .path("/common", b -> b
                        .GET(handler::listBuckets)
                        .DELETE(handler::delete)
                )
                .build();
    }

    @Override
    public void addCorsMappings(CorsRegistry registry) {
        registry.addMapping("/**")
                .allowedMethods("*")
                .allowedHeaders("*")
                .allowedOriginPatterns("*");
    }

    @Override
    public void addResourceHandlers(ResourceHandlerRegistry registry) {
        registry.addResourceHandler("/public/**")
                .addResourceLocations("classpath:/static/");
    }
}